import WaboxappAPI from './WaboxappAPI';
import IConversationOptions from './interfaces/IConversationOptions';
import { ISendResponse } from './interfaces/IResponses';
/**
 * Waboxapp Conversation class
 */
export default class Conversation {
    private options;
    private waboxappAPI;
    /**
     * @param options - Waboxapp Conversation options.
     */
    constructor(options: IConversationOptions, waboxappAPI: WaboxappAPI);
    /**
     * Send WhatsApp text message (chat).
     *
     * @param message - Text message to be send.
     * @param customUID - (Optional) Your custom unique identifier for the new message to be send. Used to identify each message and should be returned with the exact same value.
     * @returns Promise of ISendResponse object.
     */
    send(message: string, customUID?: string): Promise<ISendResponse>;
    /**
     * Send an image with URL.
     *
     * @param imageUrl - The link URL of image to be send.
     * @param optionalParams - (Optional) Object consist of: (1) "caption": Title to show on image preview; and (2) "description": Extended description to show on image preview.
     * @param customUID - (Optional) Your custom unique identifier for the new message to be send. Used to identify each message and should be returned with the exact same value.
     * @returns Promise of ISendResponse object.
     */
    sendImage(imageUrl: string, optionalParams: {
        caption?: string;
        description?: string;
    }, customUID?: string): Promise<ISendResponse>;
    /**
     * Send a link (with preview).
     *
     * @param linkUrl - The link URL to be send.
     * @param optionalParams - (Optional) Object consist of: (1) "caption": Title to show on link preview; (2) "description": Extended description to show on link preview; and (3) "urlThumb": URL of thumb image to show on link preview.
     * @param customUID - (Optional) Your custom unique identifier for the new message to be send. Used to identify each message and should be returned with the exact same value.
     * @returns Promise of ISendResponse object.
     */
    sendLink(linkUrl: string, optionalParams?: {
        caption?: string;
        description?: string;
        urlThumb?: string;
    }, customUID?: string): Promise<ISendResponse>;
    /**
     * Send media (any kind of file).
     *
     * @param mediaUrl - The link URL of file to be send.
     * @param optionalParams - (Optional) Object consist of: (1) "caption": Title to show on file preview; (2) "description": Extended description to show on file preview; and (3) "urlThumb": URL of thumb image to show on file preview.
     * @param customUID - (Optional) Your custom unique identifier for the new message to be send. Used to identify each message and should be returned with the exact same value.
     * @returns Promise of ISendResponse object.
     */
    sendMedia(mediaUrl: string, optionalParams?: {
        caption?: string;
        description?: string;
        urlThumb?: string;
    }, customUID?: string): Promise<ISendResponse>;
}
