"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var Random_1 = __importDefault(require("./Random"));
var WaboxappAPI_1 = require("./WaboxappAPI");
/**
 * Waboxapp Conversation class
 */
var Conversation = /** @class */ (function () {
    /**
     * @param options - Waboxapp Conversation options.
     */
    function Conversation(options, waboxappAPI) {
        this.options = options;
        this.waboxappAPI = waboxappAPI;
    }
    /**
     * Send WhatsApp text message (chat).
     *
     * @param message - Text message to be send.
     * @param customUID - (Optional) Your custom unique identifier for the new message to be send. Used to identify each message and should be returned with the exact same value.
     * @returns Promise of ISendResponse object.
     */
    Conversation.prototype.send = function (message, customUID) {
        if (customUID === void 0) { customUID = Random_1.default.generate(); }
        return __awaiter(this, void 0, void 0, function () {
            var data, response, error_1;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (!message) {
                            throw new Error('Mandatory parameter "message" is undefined or null.');
                        }
                        _a.label = 1;
                    case 1:
                        _a.trys.push([1, 3, , 4]);
                        data = {
                            to: this.options.phoneNumber,
                            custom_uid: customUID,
                            text: message,
                        };
                        return [4 /*yield*/, this.waboxappAPI.request(WaboxappAPI_1.WaboxappRequestEndpoint.SEND_CHAT, data)];
                    case 2:
                        response = _a.sent();
                        if (response.success) {
                            return [2 /*return*/, response];
                        }
                        else {
                            throw new Error(response.error ? response.error : 'Waboxapp API request failure.');
                        }
                        return [3 /*break*/, 4];
                    case 3:
                        error_1 = _a.sent();
                        throw error_1;
                    case 4: return [2 /*return*/];
                }
            });
        });
    };
    /**
     * Send an image with URL.
     *
     * @param imageUrl - The link URL of image to be send.
     * @param optionalParams - (Optional) Object consist of: (1) "caption": Title to show on image preview; and (2) "description": Extended description to show on image preview.
     * @param customUID - (Optional) Your custom unique identifier for the new message to be send. Used to identify each message and should be returned with the exact same value.
     * @returns Promise of ISendResponse object.
     */
    Conversation.prototype.sendImage = function (imageUrl, optionalParams, customUID) {
        if (customUID === void 0) { customUID = Random_1.default.generate(); }
        return __awaiter(this, void 0, void 0, function () {
            var data, response, error_2;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (!imageUrl) {
                            throw new Error('Mandatory parameter "imageUrl" is undefined or null.');
                        }
                        _a.label = 1;
                    case 1:
                        _a.trys.push([1, 3, , 4]);
                        data = {
                            to: this.options.phoneNumber,
                            custom_uid: customUID,
                            url: imageUrl,
                        };
                        if (optionalParams !== void 0) {
                            ;
                            data.caption = optionalParams.caption;
                            data.description = optionalParams.description;
                        }
                        return [4 /*yield*/, this.waboxappAPI.request(WaboxappAPI_1.WaboxappRequestEndpoint.SEND_IMAGE, data)];
                    case 2:
                        response = _a.sent();
                        if (response.success) {
                            return [2 /*return*/, response];
                        }
                        else {
                            throw new Error(response.error ? response.error : 'Waboxapp API request failure.');
                        }
                        return [3 /*break*/, 4];
                    case 3:
                        error_2 = _a.sent();
                        throw error_2;
                    case 4: return [2 /*return*/];
                }
            });
        });
    };
    /**
     * Send a link (with preview).
     *
     * @param linkUrl - The link URL to be send.
     * @param optionalParams - (Optional) Object consist of: (1) "caption": Title to show on link preview; (2) "description": Extended description to show on link preview; and (3) "urlThumb": URL of thumb image to show on link preview.
     * @param customUID - (Optional) Your custom unique identifier for the new message to be send. Used to identify each message and should be returned with the exact same value.
     * @returns Promise of ISendResponse object.
     */
    Conversation.prototype.sendLink = function (linkUrl, optionalParams, customUID) {
        if (customUID === void 0) { customUID = Random_1.default.generate(); }
        return __awaiter(this, void 0, void 0, function () {
            var data, response, error_3;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (!linkUrl) {
                            throw new Error('Mandatory parameter "linkUrl" is undefined or null.');
                        }
                        _a.label = 1;
                    case 1:
                        _a.trys.push([1, 3, , 4]);
                        data = {
                            to: this.options.phoneNumber,
                            custom_uid: customUID,
                            url: linkUrl,
                        };
                        if (optionalParams !== void 0) {
                            ;
                            data.caption = optionalParams.caption;
                            data.description = optionalParams.description;
                            data.url_thumb = optionalParams.urlThumb;
                        }
                        return [4 /*yield*/, this.waboxappAPI.request(WaboxappAPI_1.WaboxappRequestEndpoint.SEND_LINK, data)];
                    case 2:
                        response = _a.sent();
                        if (response.success) {
                            return [2 /*return*/, response];
                        }
                        else {
                            throw new Error(response.error ? response.error : 'Waboxapp API request failure.');
                        }
                        return [3 /*break*/, 4];
                    case 3:
                        error_3 = _a.sent();
                        throw error_3;
                    case 4: return [2 /*return*/];
                }
            });
        });
    };
    /**
     * Send media (any kind of file).
     *
     * @param mediaUrl - The link URL of file to be send.
     * @param optionalParams - (Optional) Object consist of: (1) "caption": Title to show on file preview; (2) "description": Extended description to show on file preview; and (3) "urlThumb": URL of thumb image to show on file preview.
     * @param customUID - (Optional) Your custom unique identifier for the new message to be send. Used to identify each message and should be returned with the exact same value.
     * @returns Promise of ISendResponse object.
     */
    Conversation.prototype.sendMedia = function (mediaUrl, optionalParams, customUID) {
        if (customUID === void 0) { customUID = Random_1.default.generate(); }
        return __awaiter(this, void 0, void 0, function () {
            var data, response, error_4;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (!mediaUrl) {
                            throw new Error('Mandatory parameter "mediaUrl" is undefined or null.');
                        }
                        _a.label = 1;
                    case 1:
                        _a.trys.push([1, 3, , 4]);
                        data = {
                            to: this.options.phoneNumber,
                            custom_uid: customUID,
                            url: mediaUrl,
                        };
                        if (optionalParams !== void 0) {
                            ;
                            data.caption = optionalParams.caption;
                            data.description = optionalParams.description;
                            data.url_thumb = optionalParams.urlThumb;
                        }
                        return [4 /*yield*/, this.waboxappAPI.request(WaboxappAPI_1.WaboxappRequestEndpoint.SEND_MEDIA, data)];
                    case 2:
                        response = _a.sent();
                        if (response.success) {
                            return [2 /*return*/, response];
                        }
                        else {
                            throw new Error(response.error ? response.error : 'Waboxapp API request failure.');
                        }
                        return [3 /*break*/, 4];
                    case 3:
                        error_4 = _a.sent();
                        throw error_4;
                    case 4: return [2 /*return*/];
                }
            });
        });
    };
    return Conversation;
}());
exports.default = Conversation;
//# sourceMappingURL=Conversation.js.map